pub struct CourseModuleSuotarConfiguration {Show 23 fields
pub id: Uuid,
pub created_at: DateTime<Utc>,
pub updated_at: DateTime<Utc>,
pub deleted_at: Option<DateTime<Utc>>,
pub course_module_id: Uuid,
pub paused_at: Option<DateTime<Utc>>,
pub paused_by_user_id: Option<Uuid>,
pub pause_reason: Option<String>,
pub config_checked_at: Option<DateTime<Utc>>,
pub course_code_allowed: Option<bool>,
pub config_check_message: Option<String>,
pub checked_course_code: Option<String>,
pub course_code_rejection: Option<String>,
pub last_listing_attempted_at: Option<DateTime<Utc>>,
pub last_listed_at: Option<DateTime<Utc>>,
pub last_listing_error: Option<CreditRegistrationErrorCode>,
pub consecutive_listing_failures: i32,
pub last_listed_person_count: Option<i32>,
pub last_already_linked_count: Option<i32>,
pub last_mailed_count: Option<i32>,
pub last_suppressed_by_dedup_count: Option<i32>,
pub last_suppressed_by_rate_cap_count: Option<i32>,
pub last_no_address_count: Option<i32>,
}Fields
id: Uuidcreated_at: DateTime<Utc>updated_at: DateTime<Utc>deleted_at: Option<DateTime<Utc>>course_module_id: Uuidpaused_at: Option<DateTime<Utc>>paused_by_user_id: Option<Uuid>pause_reason: Option<String>config_checked_at: Option<DateTime<Utc>>course_code_allowed: Option<bool>None means never checked, which is not the same as a failed check.
config_check_message: Option<String>checked_course_code: Option<String>The course code course_code_allowed is a verdict on.
course_code_rejection: Option<String>Suotar’s reason for not accepting checked_course_code.
last_listing_attempted_at: Option<DateTime<Utc>>last_listed_at: Option<DateTime<Utc>>last_listing_error: Option<CreditRegistrationErrorCode>consecutive_listing_failures: i32last_listed_person_count: Option<i32>last_already_linked_count: Option<i32>last_mailed_count: Option<i32>last_suppressed_by_dedup_count: Option<i32>last_suppressed_by_rate_cap_count: Option<i32>last_no_address_count: Option<i32>Trait Implementations
Sourceimpl Clone for CourseModuleSuotarConfiguration
impl Clone for CourseModuleSuotarConfiguration
Sourcefn clone(&self) -> CourseModuleSuotarConfiguration
fn clone(&self) -> CourseModuleSuotarConfiguration
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for CourseModuleSuotarConfiguration
impl ComposeSchema for CourseModuleSuotarConfiguration
Sourceimpl<'de> Deserialize<'de> for CourseModuleSuotarConfiguration
impl<'de> Deserialize<'de> for CourseModuleSuotarConfiguration
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for CourseModuleSuotarConfiguration
impl PartialEq for CourseModuleSuotarConfiguration
Sourcefn eq(&self, other: &CourseModuleSuotarConfiguration) -> bool
fn eq(&self, other: &CourseModuleSuotarConfiguration) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl ToSchema for CourseModuleSuotarConfiguration
impl ToSchema for CourseModuleSuotarConfiguration
impl StructuralPartialEq for CourseModuleSuotarConfiguration